@@ -8,7 +8,9 @@ coins = Maguro("coins.csv", delimiter=",")
 if coins.count() ==0:
     coins.load(Gaze().supported())
 crypto = Wimby(coins.unpack(), debug=True)
-crypto.dump(yesterday)
+
+crypto.add("request-network")
+crypto.analyze()
 
 # arkivist object
 momentum = crypto.momentum
