@@ -38,13 +38,6 @@ class Wimby:
     def dump(self, yesterday=None):
         pass
 
-def format_price(price):
-    if price < 1:
-        return f"{price:.8f}"
-    if price < 10:
-        return f"{price:,.6f}"
-    return f"{price:,.2f}"
-
 def _supported(coins, aliases, aliased, debug):
     supported = []
     if isinstance(coins, list):
@@ -90,17 +83,19 @@ def _historical_averages(coins, debug):
             for days in periods:
                 if len(prices) == 0:
                     prices = _prices(token, days=days)
-                    low, high = min(prices), max(prices)
-                    trends.update({"price_vs_min": (price - low)})
-                    trends.update({"price_vs_max": (price - high)})
-                    trends.update({"high": high})
-                    trends.update({"low": low})
-                wavg = trends.get(str(days), 0)
-                if wavg <= 0:
-                    wavg = _median_price(prices, days)
-                if wavg > 0:
-                    trends.update({str(days): wavg})
-                    if price > wavg:
+                    values = list(prices.values())
+                    if len(values) > 0:
+                        low, high = min(values), max(values)
+                        trends.update({"price_vs_min": (price - low)})
+                        trends.update({"price_vs_max": (price - high)})
+                        trends.update({"high": high})
+                        trends.update({"low": low})
+                median = trends.get(str(days), 0)
+                if median <= 0:
+                    median = _median_price(prices, days)
+                if median > 0:
+                    trends.update({str(days): median})
+                    if price > median:
                         pattern.append("+")
                     else:
                         pattern.append("-")
